Documentation
¶
Overview ¶
Copyright 2009 The Go Authors. All rights reserved. Use of this source code is governed by a BSD-style license that can be found in the LICENSE file.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var BufPackage = export.Exports{ {N: "cap", T: export.Func, F: bufCap}, {N: "len", T: export.Func, F: bufLen}, {N: "new", T: export.Func, F: bufNew}, {N: "read", T: export.Func, F: bufRead}, {N: "read_byte", T: export.Func, F: bufReadByte}, {N: "read_from", T: export.Func, F: bufReadFrom}, {N: "read_rune", T: export.Func, F: bufReadRune}, {N: "unread_byte", T: export.Func, F: bufUnreadByte}, }
var CoPackage = export.Exports{ {N: "run_with_timeout", T: export.Func, F: runWithTimeout}, {N: "start", T: export.Func, F: start}, }
var ErrAborted = errors.New("aborted")
var ErrProcessAlreadyStarted = errors.New("process already started")
var ExecPackage = export.Exports{ {N: "exec", T: export.Func, F: execExec}, {N: "with_dir", T: export.Func, F: execWithDir}, {N: "with_env", T: export.Func, F: execWithEnv}, {N: "with_partial_env", T: export.Func, F: execWithPartialEnv}, {N: "with_stderr", T: export.Func, F: execWithStderr}, }
var GlobalPackage = export.Exports{ {N: "$close_iter", T: export.Func, F: close_iter}, {N: "$concat", T: export.Func, F: concat}, {N: "$exec", T: export.Func, F: execExec}, {N: "$format", T: export.Func, F: format}, {N: "$home", T: export.Func, F: internalHomeDir}, {N: "avg", T: export.Func, F: avg}, {N: "count", T: export.Func, F: count}, {N: "first", T: export.Func, F: first}, {N: "flatten", T: export.Func, F: flatten}, {N: "group", T: export.Func, F: group}, {N: "has", T: export.Func, F: has}, {N: "hist", T: export.Func, F: hist}, {N: "in", T: export.Func, F: in}, {N: "iterate", T: export.Func, F: iterate}, {N: "len", T: export.Func, F: Len}, {N: "map", T: export.Func, F: imap}, {N: "map_reduce", T: export.Func, F: mapReduce}, {N: "max", T: export.Func, F: max}, {N: "min", T: export.Func, F: min}, {N: "mod", T: export.Func, F: mod}, {N: "narg", T: export.Func, F: narg}, {N: "next", T: export.Func, F: next}, {N: "prompt", T: export.Func, F: prompt}, {N: "range", T: export.Func, F: range_}, {N: "read", T: export.Func, F: read}, {N: "reduce", T: export.Func, F: reduce}, {N: "regex", T: export.Func, F: regex}, {N: "sha1", T: export.Func, F: sha1}, {N: "shuffle", T: export.Func, F: shuffle}, {N: "skip", T: export.Func, F: skip}, {N: "skip_until", T: export.Func, F: skipUntil}, {N: "skip_while", T: export.Func, F: skipWhile}, {N: "sleep", T: export.Func, F: sleep}, {N: "sort", T: export.Func, F: sort}, {N: "stream", T: export.Func, F: stream}, {N: "sum", T: export.Func, F: sum}, {N: "take", T: export.Func, F: take}, {N: "take_until", T: export.Func, F: takeUntil}, {N: "take_while", T: export.Func, F: takeWhile}, {N: "type", T: export.Func, F: typep}, {N: "unique", T: export.Func, F: unique}, }
var MathPackage = export.Exports{ {N: "trunc", T: export.Func, F: mathTrunc}, }
Functions ¶
func ListFromIter ¶ added in v0.0.3
func RegisterAll ¶
func RegisterAll(registry BuiltinRegistry)
Types ¶
type Buffer ¶
type Buffer struct {
core.WriterBase
// contains filtered or unexported fields
}
type BuiltinRegistry ¶
type LimitedReader ¶
type LimitedReader struct {
// contains filtered or unexported fields
}
func NewLimitedReader ¶
func NewLimitedReader(r vm.Reader, n int64) *LimitedReader
func (*LimitedReader) Close ¶
func (r *LimitedReader) Close() error
func (*LimitedReader) String ¶
func (r *LimitedReader) String() string
func (*LimitedReader) Traits ¶
func (r *LimitedReader) Traits() vm.Traits
func (*LimitedReader) Type ¶
func (r *LimitedReader) Type() string
Source Files
¶
- buf.go
- close_iter.go
- co_run_with_timeout.go
- co_start.go
- concat.go
- exec.go
- first.go
- flatten.go
- format.go
- has.go
- hist.go
- imap.go
- in.go
- iterate.go
- len.go
- lib.go
- map_reduce.go
- math.go
- mod.go
- narg.go
- next.go
- path_expr.go
- prefix_suffix_saver.go
- prompt.go
- range.go
- read.go
- reduce.go
- regex.go
- sha1.go
- skip.go
- skip_until.go
- skip_while.go
- sleep.go
- sort.go
- stat.go
- stream_lines.go
- take.go
- take_until.go
- take_while.go
- type.go
- unique.go
- user_home_dir.go
- util.go
Click to show internal directories.
Click to hide internal directories.